@@ -2,5 +2,4 @@ import widget
 try:
     from pyramid.view import static
     tiny_mce = static('tinymce/jscripts/tiny_mce')
-except ImportError:
-    pass
\ No newline at end of file
+except ImportError: pass                                    #pragma NO COVERAGE
\ No newline at end of file
